pub struct Stream<P: Protocol> { /* private fields */ }Expand description
Decoded message stream over the same opaque router and lease.
Implementations
Sourceimpl<P: Protocol> Stream<P>
impl<P: Protocol> Stream<P>
Sourcepub async fn send<M: IntoOutboundMessage<P>>(
&self,
message: M,
) -> ClientResult<()>
pub async fn send<M: IntoOutboundMessage<P>>( &self, message: M, ) -> ClientResult<()>
Send a native or already-encoded payload using the selected codec.
Sourcepub async fn recv(&mut self) -> ClientResult<Option<Message>>
pub async fn recv(&mut self) -> ClientResult<Option<Message>>
Receive an inspectable message, including unknown names and peer errors.
Sourcepub fn into_parts(self) -> (StreamSender<P>, StreamReceiver<P>)
pub fn into_parts(self) -> (StreamSender<P>, StreamReceiver<P>)
Split into owned handles while preserving one receiver and the ID lease.